.. ORCID Hub documentation master file, created by
   sphinx-quickstart on Tue Nov 28 17:15:32 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ORCID Hub's documentation!
=====================================

.. image:: https://travis-ci.org/Royal-Society-of-New-Zealand/NZ-ORCID-Hub.svg?branch=master
   :target: https://travis-ci.org/Royal-Society-of-New-Zealand/NZ-ORCID-Hub
   :alt: Build Status

.. image:: https://coveralls.io/repos/github/Royal-Society-of-New-Zealand/NZ-ORCID-Hub/badge.svg
   :target: https://coveralls.io/github/Royal-Society-of-New-Zealand/NZ-ORCID-Hub
   :alt: Coverage Status

.. image:: https://readthedocs.org/projects/nz-orcid-hub/badge/
   :target: http://docs.orcidhub.org.nz/
   :alt: RTD Status

The home of development for the New Zealand ORCID Hub.

Because New Zealand ORCID Hub is fun to use.

Table of Contents
^^^^^^^^^^^^^^^^^

.. toctree::
   :maxdepth: 1
   :name: masterdoc

   installation
   shibboleth
   customising_email_messages
   writing_affiliation_items
   writing_funding_items
   fundings_schema
   writing_work_items
   works_schema
   writing_peer_review_items
   peer_review_schema

   ORCID API Specification <orcid_api_spec>

   app_registration
   orcid_api_proxy
   webhooks

   development_env
   docker
   virtualbox
   sendmail
   troubleshooting
   db_recovery
   pg_upgrade


Indices and tables
^^^^^^^^^^^^^^^^^^

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
